<?php

class EquipController extends AdmController {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Equip::model()->updateBalance();
            Yii::app()->session['sidebar_active'] = 'equip';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        $grids = $this->getGridData();
        $this->render('index', array('grids' => $grids));
    }

    public function actionAjaxList() {
        $grids = $this->getGridData($_POST['txtsearch']);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '') {
        $criteria = new CDbCriteria;
        $criteria->condition = "name LIKE :txtsearch or detail LIKE :txtsearch";
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 'name asc';

        $count = Equip::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';
        $pages->pageSize = Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Equip::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionAjaxCreate() {
        $model = new Equip;
        $this->renderPartial('_form', array('model' => $model));
    }

    public function actionAjaxUpdate() {
        $id = $_POST['id'];
        $model = Equip::model()->findByPk($id);

        if (isset($_POST['save'])) {
            if ($id == '') {
                $model = new Equip;
            }

            $model->name = $_POST['name'];
            $model->detail = $_POST['detail'];
            $model->amount = (int)$_POST['amount'];
            $model->unitname = $_POST['unitname'];
            $model->balance = (int)$_POST['balance'];
            $model->status = (int)$_POST['status'];

            $data = $model->checkDuplicate($_POST['id'], $_POST['name']);
            if ($data['msg'] == '0') {
                $msg = 0;
                $msgText = '';
                if (!$model->save()) {
                    $msg = 1;
                    $msgText = array_shift($model->getErrors());
                }
                $data = array('msg' => $msg, 'msgText' => $msgText);
            }

            echo CJSON::encode($data);
            yii::app()->end();
        }
        $this->renderPartial('_form', array('model' => $model));
    }

    public function actionAjaxDelete() {
        $msg = '0';
        $row = Equip::model()->findByPk($_POST['id']);
        $row->delete();
        $data['msg'] = $msg;
        echo CJSON::encode($data);
    }

    
    //เปิด Modal เพื่อเลือกข้อมูล
    public function actionModal() {
        $txtsearch = (isset(Yii::app()->session['equip_modal_txtsearch'])) ? Yii::app()->session['equip_modal_txtsearch'] : '';
        $grids = $this->getGridDataModal();
        $this->renderPartial('//equip/modal', array('grids' => $grids, 'txtsearch' => $txtsearch));
    }

    public function actionAjaxListModal() {
        $txtsearch = trim($_POST['txtsearch']);
        Yii::app()->session['equip_modal_txtsearch'] = $txtsearch;
        
        $grids = $this->getGridDataModal($txtsearch);
        $this->renderPartial('//equip/_gridview_modal', array('grids' => $grids));
    }

    public function getGridDataModal($txtsearch = '') {
        $criteria = new CDbCriteria;
        $criteria->condition = "(name LIKE :txtsearch)";
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 'name asc';

        $count = Equip::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxListModal';
        $pages->pageSize = 10; //Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Equip::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }
}
