<?php

class FacultyController extends AdmController {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Yii::app()->session['sidebar_active'] = 'faculty';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        $grids = $this->getGridData();
        $this->render('index', array('grids' => $grids));
    }

    public function actionAjaxList() {
        $grids = $this->getGridData($_POST['txtsearch']);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '') {
        $criteria = new CDbCriteria;
        $criteria->condition = "name LIKE :txtsearch or code LIKE :txtsearch";
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 'code asc';

        $count = Faculty::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';
        $pages->pageSize = Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Faculty::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionAjaxCreate() {
        $model = new Faculty;
        $this->renderPartial('_form', array('model' => $model));
    }

    public function actionAjaxUpdate() {
        $id = $_POST['id'];
        $model = Faculty::model()->findByPk($id);

        if (isset($_POST['save'])) {
            if ($id == '') {
                $model = new Faculty;
            }
            $model->code = $_POST['code'];
            $model->name = $_POST['name'];

            $data = $model->checkDuplicate($_POST['id'], $_POST['code']);
            if ($data['msg'] == '0') {
                $msg = 0;
                $msgText = '';
                if (!$model->save()) {
                    $msg = 1;
                    $msgText = array_shift($model->getErrors());
                }
                $data = array('msg' => $msg, 'msgText' => $msgText);
            }

            echo CJSON::encode($data);
            yii::app()->end();
        }
        $this->renderPartial('_form', array('model' => $model));
    }

    public function actionAjaxDelete() {
        $facultyId = (int) $_POST['id'];
        $msg = '0';
        $msgText = '';

        $depart = Depart::model()->findByAttributes(array('faculty_id' => $facultyId));
        if (isset($depart->id)) {
            $msgText = "ไม่สามารถลบรายการได้เนื่องจากหน่วยงานนี้ ได้ถูกนำไปใช้กับข้อมูลแผนกต่างๆ แล้ว";
            $msg = '1';
        } else {
            $row = Faculty::model()->findByPk($facultyId);
            $row->delete();
        }

        $data['msg'] = $msg;
        $data['msgText'] = $msgText;
        echo CJSON::encode($data);
    }

}
