<?php

class FunctionsheetController extends AdmController {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Yii::app()->session['sidebar_active'] = 'functionsheet';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        $txtsearch = Yii::app()->session['functionsheet_txtsearch'];
        $fdate = Yii::app()->session['functionsheet_fdate'];
        $edate = Yii::app()->session['functionsheet_edate'];

        $grids = $this->getGridData($txtsearch, $fdate, $edate);
        $this->render('index', array(
            'grids' => $grids,
            'txtsearch' => $txtsearch,
            'fdate' => MyDate::dateToText($fdate),
            'edate' => MyDate::dateToText($edate)
        ));
    }

    public function actionAjaxList() {
        $fdate = MyDate::dateToMysql($_POST['fdate']);
        $edate = MyDate::dateToMysql($_POST['edate']);

        Yii::app()->session['functionsheet_txtsearch'] = $_POST['txtsearch'];
        Yii::app()->session['functionsheet_fdate'] = $fdate;
        Yii::app()->session['functionsheet_edate'] = $edate;

        $grids = $this->getGridData($_POST['txtsearch'], $fdate, $edate);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '', $fdate = '', $edate = '') {
        if ($fdate == '') {
            $fdate = '1900-01-01';
        }
        if ($edate == '') {
            $edate = '2500-01-01';
        }

        $criteria = new CDbCriteria;
        $criteria->condition = "(docno LIKE :txtsearch or organizer LIKE :txtsearch or company LIKE :txtsearch or tel LIKE :txtsearch)";
        $criteria->condition.= " AND (docdate between '$fdate' AND '$edate')";
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 'docdate desc';

        $count = Functionsheet::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';
        $pages->pageSize = Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Functionsheet::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionAjaxDocRun() {
        $data['docno'] = Functionsheet::model()->getDocrun();
        echo CJSON::encode($data);
    }

    public function actionCreate() {
        $model = new Functionsheet;
        $model->docno = $model->getDocrun();
        $model->docdate = date('Y-m-d');
        $this->render('form', array('model' => $model));
    }

    public function actionAjaxValidate() {
        $model = new Functionsheet;
        $data = $model->checkDuplicate($_POST['id'], $_POST['docno']);
        echo CJSON::encode($data);
    }

    public function actionUpdate() {
        $id = (isset($_GET['id'])) ? (int) $_GET['id'] : '';
        $model = Functionsheet::model()->findByPk($id);

        if (isset($_POST['Functionsheet'])) {
            if ($_POST['id'] == '') {
                $model = new Functionsheet;
            } else {
                //submit มาจาก form
                $model = Functionsheet::model()->findByPk($_POST['id']);
                $model->count_edit+=1;
                $model->last_edit = date('Y-m-d H:i:s');
            }

            $model->attributes = $_POST['Functionsheet'];
            $model->docdate = MyDate::dateToMysql($model->docdate);
            $model->accounts_price = MyFn::numberToMySql($model->accounts_price);

            if ($model->save()) {
                Yii::app()->user->setFlash('success', 'บันทึกข้อมูลเรียบร้อย');
                $this->redirect(array('update', 'id' => $model->id));
            } else {
                Yii::app()->user->setFlash('save_error', 'ไม่สามารถบันทึกข้อมูลได้เนื่องจาก ' . $model->getErrors());
                $this->redirect(array('update', 'id' => $model->id));
            }
        }

        $grids_food = $this->getGridDataFood($id);
        $this->render('form', array('model' => $model, 'grids_food' => $grids_food));
    }

    //คัดลอก
    public function actionCopy() {
        $id = (isset($_GET['id'])) ? (int) $_GET['id'] : '0';
        $model = Functionsheet::model()->findByPk($id);
        if ($model !== NULL) {
            $newModel = new Functionsheet;
            $newModel->attributes = $model->attributes;

            $newModel->docno = $newModel->getDocrun();
            $newModel->docdate = date('Y-m-d');
            $newModel->count_edit = '-1';
            $newModel->last_edit = '';
            if ($newModel->save()) {
                $models = Functionfood::model()->findAllByAttributes(array('functionsheet_id' => $model->id));
                foreach ($models as $r) {
                    $food = new Functionfood;
                    $food->functionsheet_id = $newModel->id;
                    $food->no = $r->no;
                    $food->title = $r->title;
                    $food->detail = $r->detail;
                    $food->save();
                }
            }
            $this->redirect(array('update', 'id' => $newModel->id));
        } else {
            $this->redirect(array('index'));
        }
    }

    public function actionAjaxDelete() {
        $msg = '0';
        $id = (int) $_POST['id'];
        $row = Functionsheet::model()->findByPk($_POST['id']);
        if ($row->delete()) {
            Functionfood::model()->deleteAll('functionsheet_id=?', array($id));
        }
        $data['msg'] = $msg;
        echo CJSON::encode($data);
    }

    //Food
    public function actionAjaxListFood() {
        $grids_food = $this->getGridDataFood($_POST['functionsheet_id']);
        $this->renderPartial('_gridview_food', array('grids_food' => $grids_food));
    }

    public function getGridDataFood($functionsheet_id) {
        $criteria = new CDbCriteria;
        $criteria->condition = "functionsheet_id='$functionsheet_id'";
        $criteria->order = 'abs(no) asc';

        $models = Functionfood::model()->findAll($criteria);
        return array('models' => $models);
    }

    public function actionAjaxSaveFood() {
        $id = (int) $_POST['id'];
        $model = Functionfood::model()->findByPk($id);

        if ($model === NULL) {
            $model = new Functionfood;
        }

        $model->functionsheet_id = $_POST['functionsheet_id'];
        $model->no = $_POST['no'];
        $model->title = $_POST['title'];
        $model->detail = $_POST['detail'];
        $model->save();

        echo true;
    }

    public function actionAjaxUpdateFood() {
        $id = (int) $_POST['id'];
        $model = Functionfood::model()->findByPk($id);
        echo CJSON::encode($model);
    }

    public function actionAjaxDeleteFood() {
        $msg = '0';
        $row = Functionfood::model()->findByPk($_POST['id']);
        $row->delete();
        $data['msg'] = $msg;
        echo CJSON::encode($data);
    }

}
