<?php

class RoomController extends AdmController {

    protected function beforeAction($action) {
        if (parent::beforeAction($action)) {
            Yii::app()->session['sidebar_active'] = 'room';
            return true;
        }
        return false;
    }

    public function actionIndex() {
        $txtfield = Yii::app()->session['room_txtfield'];
        $txtsearch = Yii::app()->session['room_txtsearch'];

        $grids = $this->getGridData($txtsearch, $txtfield);
        $this->render('index', array('grids' => $grids,
            'txtsearch' => $txtsearch, 'txtfield' => $txtfield));
    }

    public function actionAjaxList() {
        Yii::app()->session['room_txtfield'] = $_POST['txtfield'];
        Yii::app()->session['room_txtsearch'] = $_POST['txtsearch'];

        $grids = $this->getGridData($_POST['txtsearch'], $_POST['txtfield']);
        $this->renderPartial('_gridview', array('grids' => $grids));
    }

    public function getGridData($txtsearch = '', $txtfield = '') {
        $criteria = new CDbCriteria;
        $criteria->condition = "name LIKE :txtsearch or place LIKE :txtsearch";
        if ($txtfield != '') {
            $criteria->condition = "$txtfield LIKE :txtsearch";
        }
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 'name asc';

        $count = Room::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxList';
        $pages->pageSize = Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Room::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    public function actionCreate() {
        $model = new Room;
        $this->render('form', array('model' => $model));
    }

    public function actionAjaxValidate() {
        $model = new Room;
        $data = $model->checkDuplicate($_POST['id'], $_POST['name']);
        echo CJSON::encode($data);
    }

    public function actionUpdate() {
        $id = (isset($_GET['id'])) ? (int) $_GET['id'] : '';
        $model = Room::model()->findByPk($id);

        if (isset($_POST['Room'])) {
            if ($_POST['id'] == '') {
                $model = new Room;
            } else {
                //submit มาจาก form
                $model = Room::model()->findByPk($_POST['id']);
            }
            
            $model->attributes = $_POST['Room'];

            if ($model->save()) {
                /* === อัพโหลดไฟล์รูปรถ=== */
                for ($i = 1; $i < 5; $i++) {
                    if (isset($_FILES["picture$i"])) {
                        $dir = Yii::getPathOfAlias("webroot.fileupload.room");
                        $uploadedFile = CUploadedFile::getInstanceByName("picture$i");
                        if ($uploadedFile !== null) {
                            $new_name = $model->id . "_$i." . $uploadedFile->getExtensionName();  //เปลี่ยนชื่อไฟล์

                            $uploadedFile->saveAs($dir . '/' . $new_name);
                            $row = Room::model()->findByPk($model->id);

                            $fieldName = "picture$i";
                            $row->$fieldName = $new_name;
                            $row->save();     //เก็บข้อมูลลง Database

                            Yii::import('application.extensions.image.Image');
                            $image = new Image($dir . '/' . $new_name);
                            if ($image->width > 600 || $image->height > 480) {
                                $image->resize(600, 480, Image::AUTO);
                                $image->save();
                            }
                        }
                    }
                }

                Yii::app()->user->setFlash('success', 'บันทึกข้อมูลเรียบร้อย');
                $this->redirect(array('update', 'id' => $model->id));
            } else {
                Yii::app()->user->setFlash('save_error', 'ไม่สามารถบันทึกข้อมูลได้เนื่องจาก ' . $model->getErrors());
                $this->redirect(array('update', 'id' => $model->id));
            }
        }
        $this->render('form', array('model' => $model));
    }

    public function actionAjaxDelete() {
        $msg = '0';
        $row = Room::model()->findByPk($_POST['id']);
        $row->delete();
        $data['msg'] = $msg;
        echo CJSON::encode($data);
    }

    //เปิด Modal เพื่อเลือกข้อมูล
    public function actionModal() {
        $this->layout = '//layouts/modalwindow/column1';
        $grids = $this->getGridDataModal();
        $this->render('modal', array('grids' => $grids));
    }

    public function actionAjaxListModal() {
        $txtsearch = $_POST['txtsearch'];

        $grids = $this->getGridDataModal($txtsearch);
        $this->renderPartial('_gridview_modal', array('grids' => $grids,
            'txtsearch' => $txtsearch));
    }

    public function getGridDataModal($txtsearch = '') {
        $criteria = new CDbCriteria;
        $criteria->condition = "name LIKE :txtsearch or place LIKE :txtsearch";
        $criteria->params = array(':txtsearch' => "%$txtsearch%");
        $criteria->order = 'name asc';

        $count = Room::model()->count($criteria);

        $pages = new CPagination($count);
        $pages->route = 'ajaxListModal';
        $pages->pageSize = Yii::app()->params['pageSize'];
        $pages->applyLimit($criteria);
        $models = Room::model()->findAll($criteria);

        return array('models' => $models, 'pages' => $pages, 'count' => $count);
    }

    //คำนวนค่าเช่าห้อง
    public function actionAjaxGetCalculate() {
        $room_id = (int) $_POST['room_id'];
        $room = Room::model()->findByPk($room_id);

        $start_date = MyDate::dateToMysql($_POST['start_date']) . " " . $_POST['start_time_f'] . ":" . $_POST['start_time_e'];
        $end_date = MyDate::dateToMysql($_POST['end_date']) . " " . $_POST['end_time_f'] . ":" . $_POST['end_time_e'];

        $minute = MyDate::compareDate(array('begin' => $start_date, 'end' => $end_date), false);

        $data = array(
            'room_rate' => number_format($room->rate, 2),
            'room_money' => number_format($room->rate * $minute, 2)
        );

        echo CJSON::encode($data);
    }
    
    public function actionTypeAhead(){
        $sql = "SELECT tb_room.place FROM tb_room GROUP BY tb_room.place ORDER BY tb_room.place ASC";
        $models = Yii::app()->db->createCommand($sql)->queryAll();
        echo CJSON::encode($models);
    }

}
