<?php

/**
 * This is the model class for table "tb_company".
 *
 * The followings are the available columns in table 'tb_company':
 * @property integer $id
 * @property string $name
 * @property string $manager
 * @property string $address
 * @property string $province
 * @property string $tel
 * @property string $fax
 * @property string $en1
 * @property string $en2
 * @property string $en3
 * @property string $en4
 * @property string $en5
 * @property string $webheader
 * @property integer $approve_auto
 * @property integer $cancel_auto
 * @property integer $reserv_minute
 * @property string $logo
 */
class Company extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_company';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('approve_auto, cancel_auto, reserv_minute', 'numerical', 'integerOnly' => true),
            array('name, manager, province, tel, fax, webheader', 'length', 'max' => 100),
            array('logo', 'length', 'max' => 20),
            array('address, en1, en2, en3, en4, en5', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, name, manager, address, province, tel, fax, en1, en2, en3, en4, en5, webheader, approve_auto, cancel_auto, reserv_minute, logo', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'name' => 'Name',
            'manager' => 'Manager',
            'address' => 'Address',
            'province' => 'Province',
            'tel' => 'Tel',
            'fax' => 'Fax',
            'en1' => 'En1',
            'en2' => 'En2',
            'en3' => 'En3',
            'en4' => 'En4',
            'en5' => 'En5',
            'webheader' => 'Webheader',
            'approve_auto' => 'Approve Auto',
            'cancel_auto' => 'Cancel Auto',
            'reserv_minute' => 'Reserv Minute',
            'logo' => 'Logo',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('manager', $this->manager, true);
        $criteria->compare('address', $this->address, true);
        $criteria->compare('province', $this->province, true);
        $criteria->compare('tel', $this->tel, true);
        $criteria->compare('fax', $this->fax, true);
        $criteria->compare('en1', $this->en1, true);
        $criteria->compare('en2', $this->en2, true);
        $criteria->compare('en3', $this->en3, true);
        $criteria->compare('en4', $this->en4, true);
        $criteria->compare('en5', $this->en5, true);
        $criteria->compare('webheader', $this->webheader, true);
        $criteria->compare('approve_auto', $this->approve_auto);
        $criteria->compare('cancel_auto', $this->cancel_auto);
        $criteria->compare('reserv_minute', $this->reserv_minute);
        $criteria->compare('logo', $this->logo, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Company the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    //แสดง path รูปภาพ
    public function getImagePath($id) {
        $model = self::model()->findByPk($id);
        $pict = '';
        if ($model !== null) {
            //ตรวจสอบว่ามีภาพนี้อยู่จริงหรือไม่
            Yii::import('application.extensions.cfile.CFile');
            $cfile = new CFile();

            $dir = Yii::getPathOfAlias("webroot.fileupload.user");
            $myfile = $cfile->set($dir . "/" . $model->logo, true);
            if ($myfile->exists && $myfile->isfile) {
                $pict = Yii::app()->baseUrl . "/fileupload/user/" . $model->logo . "?" . rand(1, 999);
            }
        }

        return $pict;
    }

}
