<?php

/**
 * This is the model class for table "tb_equip".
 *
 * The followings are the available columns in table 'tb_equip':
 * @property integer $id
 * @property string $name
 * @property string $detail
 * @property integer $amount
 * @property string $unitname
 * @property integer $status
 * @property integer $balance
 */
class Equip extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_equip';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('amount, status, balance', 'numerical', 'integerOnly' => true),
            array('name', 'length', 'max' => 100),
            array('unitname', 'length', 'max' => 50),
            array('detail', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, name, detail, amount, unitname, status, balance', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'name' => 'Name',
            'detail' => 'Detail',
            'amount' => 'Amount',
            'unitname' => 'Unitname',
            'status' => 'Status',
            'balance' => 'Balance',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('detail', $this->detail, true);
        $criteria->compare('amount', $this->amount);
        $criteria->compare('unitname', $this->unitname, true);
        $criteria->compare('status', $this->status);
        $criteria->compare('balance', $this->balance);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Equip the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * ตรวจสอบชื่อซ้ำ
     */
    function checkDuplicate($id, $value) {
        $model = $this->findByAttributes(array('name' => $value));

        $msg = '0';
        $msgText = '';
        if ($model !== null) {
            if ($model->id != $id) {
                $msgText = "ชื่ออุปกรณ์นี้ $value มีการใช้งานแล้ว...กรุณาเปลี่ยนใหม่.";
                $msg = '1';
            }
        }

        return array('msg' => $msg, 'msgText' => $msgText);
    }

    //เพิ่มจำนวน
    function increment($equipID, $amount) {
        $model = $this->findByPk($equipID);
        if ($model !== null) {
            if ($model->amount > 0) {
                $model->balance += $amount;
                $model->save();
            }
        }

        return true;
    }

    //ลดจำนวน
    function decrement($equipID, $amount) {
        $model = $this->findByPk($equipID);
        if ($model !== null) {
            if ($model->amount > 0) {
                $model->balance -= $amount;
                $model->save();
            }
        }

        return true;
    }

    //ปรับปรุงจำนวนคงเหลือแล้วอัพเดทสถานะใน EquipOrder
    function updateBalance() {
        $now = date('Y-m-d H:i:s');
        $models = EquipOrder::model()->findAll(array("condition" => "return_stock='0' AND end_date <= '$now'"));
        foreach ($models as $r) {
            $model = EquipOrder::model()->findByPk($r->id);
            if ($model !== null) {
                $model->return_stock = 1;
                if ($model->save()) {
                    self::model()->increment($r->equip_id, $r->amount);
                }
            }
        }
        
        return true;
    }

}
