<?php

/**
 * This is the model class for table "tb_equip_order".
 *
 * The followings are the available columns in table 'tb_equip_order':
 * @property integer $id
 * @property integer $reserv_id
 * @property integer $equip_id
 * @property integer $amount
 * @property string $description
 * @property string $end_date
 * @property integer $return_stock
 */
class EquipOrder extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_equip_order';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('reserv_id, equip_id, end_date', 'required'),
            array('reserv_id, equip_id, amount, return_stock', 'numerical', 'integerOnly' => true),
            array('description', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, reserv_id, equip_id, amount, description, end_date, return_stock', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'equip' => array(self::BELONGS_TO, 'Equip', 'equip_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'reserv_id' => 'Reserv',
            'equip_id' => 'Equip',
            'amount' => 'Amount',
            'description' => 'Description',
            'end_date' => 'End Date',
            'return_stock' => 'Return Stock',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('reserv_id', $this->reserv_id);
        $criteria->compare('equip_id', $this->equip_id);
        $criteria->compare('amount', $this->amount);
        $criteria->compare('description', $this->description, true);
        $criteria->compare('end_date', $this->end_date, true);
        $criteria->compare('return_stock', $this->return_stock);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return EquipOrder the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function updateStatus($equipOrderID, $returnStock = 1) {
        $model = $this->model()->findByPk($equipOrderID);

        if ($model !== null) {
            if ($returnStock === 0) {
                $reserv = Reserv::model()->findByPk($model->reserv_id);
                if ($reserv !== null) {
                    $model->end_date = $reserv->end_date;
                }
            }
            $model->return_stock = $returnStock;
            $model->save();
        }

        return true;
    }

}
