<?php

/**
 * This is the model class for table "tb_functionsheet".
 *
 * The followings are the available columns in table 'tb_functionsheet':
 * @property integer $id
 * @property string $docno
 * @property string $docdate
 * @property string $organizer
 * @property string $company
 * @property string $tel
 * @property string $daybook
 * @property string $datebook
 * @property string $timebook
 * @property integer $room_id
 * @property string $guaranteed
 * @property string $accountto
 * @property string $address
 * @property string $pricetext
 * @property string $comment
 * @property string $booked_by
 * @property string $timetable
 * @property string $accounts
 * @property integer $accounts_price
 * @property string $food_ar
 * @property string $food_sp
 * @property string $beverage
 * @property string $roomsetup
 * @property string $florist
 * @property string $artist
 * @property string $av
 * @property string $pr
 * @property string $approve
 * @property string $position
 * @property integer $count_edit
 * @property string $last_edit
 * @property string $bookbyname
 * @property string $bookbyposition
 */
class Functionsheet extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tb_functionsheet';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('room_id, accounts_price, count_edit', 'numerical', 'integerOnly' => true),
            array('docno, tel, daybook, datebook, timebook', 'length', 'max' => 50),
            array('organizer, guaranteed, accountto, pricetext, booked_by, pr, approve, position, bookbyname, bookbyposition', 'length', 'max' => 100),
            array('company', 'length', 'max' => 250),
            array('docdate, address, comment, timetable, accounts, food_ar, food_sp, beverage, roomsetup, florist, artist, av, last_edit', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, docno, docdate, organizer, company, tel, daybook, datebook, timebook, room_id, guaranteed, accountto, address, pricetext, comment, booked_by, timetable, accounts, accounts_price, food_ar, food_sp, beverage, roomsetup, florist, artist, av, pr, approve, position, count_edit, last_edit, bookbyname, bookbyposition', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'room' => array(self::BELONGS_TO, 'Room', 'room_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'docno' => 'Docno',
            'docdate' => 'Docdate',
            'organizer' => 'Organizer',
            'company' => 'Company',
            'tel' => 'Tel',
            'daybook' => 'Daybook',
            'datebook' => 'Datebook',
            'timebook' => 'Timebook',
            'room_id' => 'Room',
            'guaranteed' => 'Guaranteed',
            'accountto' => 'Accountto',
            'address' => 'Address',
            'pricetext' => 'Pricetext',
            'comment' => 'Comment',
            'booked_by' => 'Booked By',
            'timetable' => 'Timetable',
            'accounts' => 'Accounts',
            'accounts_price' => 'Accounts Price',
            'food_ar' => 'Food Ar',
            'food_sp' => 'Food Sp',
            'beverage' => 'Beverage',
            'roomsetup' => 'Roomsetup',
            'florist' => 'Florist',
            'artist' => 'Artist',
            'av' => 'Av',
            'pr' => 'Pr',
            'approve' => 'Approve',
            'position' => 'Position',
            'count_edit' => 'Count Edit',
            'last_edit' => 'Last Edit',
            'bookbyname' => 'Bookbyname',
            'bookbyposition' => 'Bookbyposition',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('docno', $this->docno, true);
        $criteria->compare('docdate', $this->docdate, true);
        $criteria->compare('organizer', $this->organizer, true);
        $criteria->compare('company', $this->company, true);
        $criteria->compare('tel', $this->tel, true);
        $criteria->compare('daybook', $this->daybook, true);
        $criteria->compare('datebook', $this->datebook, true);
        $criteria->compare('timebook', $this->timebook, true);
        $criteria->compare('room_id', $this->room_id);
        $criteria->compare('guaranteed', $this->guaranteed, true);
        $criteria->compare('accountto', $this->accountto, true);
        $criteria->compare('address', $this->address, true);
        $criteria->compare('pricetext', $this->pricetext, true);
        $criteria->compare('comment', $this->comment, true);
        $criteria->compare('booked_by', $this->booked_by, true);
        $criteria->compare('timetable', $this->timetable, true);
        $criteria->compare('accounts', $this->accounts, true);
        $criteria->compare('accounts_price', $this->accounts_price);
        $criteria->compare('food_ar', $this->food_ar, true);
        $criteria->compare('food_sp', $this->food_sp, true);
        $criteria->compare('beverage', $this->beverage, true);
        $criteria->compare('roomsetup', $this->roomsetup, true);
        $criteria->compare('florist', $this->florist, true);
        $criteria->compare('artist', $this->artist, true);
        $criteria->compare('av', $this->av, true);
        $criteria->compare('pr', $this->pr, true);
        $criteria->compare('approve', $this->approve, true);
        $criteria->compare('position', $this->position, true);
        $criteria->compare('count_edit', $this->count_edit);
        $criteria->compare('last_edit', $this->last_edit, true);
        $criteria->compare('bookbyname', $this->bookbyname, true);
        $criteria->compare('bookbyposition', $this->bookbyposition, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Functionsheet the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * ตรวจสอบรหัสซ้ำ
     */
    function checkDuplicate($id, $value) {
        $model = $this->findByAttributes(array('docno' => $value));

        $msg = '0';
        $msgText = '';
        if ($model !== null) {
            if ($model->id != $id) {
                $msgText = "เลขที่ FUNCTION $value มีการใช้งานแล้ว...กรุณาเปลี่ยนใหม่.";
                $msg = '1';
            }
        }

        return array('msg' => $msg, 'msgText' => $msgText);
    }

    //สร้างเลขที่เอกสาร
    public function getDocrun() {
        $prefix = MyDate::currentYearMonthThai();
        ;
        $sql = "Select Max(substr(docno,-4))+1 as maxId from tb_functionsheet where docno LIKE '$prefix%'";
        $query = Yii::app()->db->createCommand($sql)->queryRow();
        if ($query['maxId'] == null) {
            return $prefix . sprintf("%04d", 1);
        } else {
            return $prefix . sprintf("%04d", $query['maxId']);
        }
    }

}
